Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1200)

Unified Diff: ui/views/controls/textfield/textfield.h

Issue 2341633006: MacViews/a11y: Allow accessibility clients to update the selected text. (Closed)
Patch Set: Make set value callbacks not have a const bool |replace| arg. Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ui/views/controls/textfield/textfield.h
diff --git a/ui/views/controls/textfield/textfield.h b/ui/views/controls/textfield/textfield.h
index 55353ee8a4874498dbeff19c73dd9df4b11a7c6d..427b4d0f8bf4183e7c7c6fc9b2a224bbbdbd08d4 100644
--- a/ui/views/controls/textfield/textfield.h
+++ b/ui/views/controls/textfield/textfield.h
@@ -347,8 +347,9 @@ class VIEWS_EXPORT Textfield : public View,
// Handles a request to change the value of this text field from software
// using an accessibility API (typically automation software, screen readers
- // don't normally use this). Sets the value and clears the selection.
- void AccessibilitySetValue(const base::string16& new_value);
+ // don't normally use this). Sets the value and clears the selection. If
+ // |replace| is set, insert at the cursor or replace selected text.
+ void AccessibilitySetValue(const base::string16& new_value, bool replace);
// Updates the painted background color.
void UpdateBackgroundColor();

Powered by Google App Engine
This is Rietveld 408576698